# coding: utf-8
# La ligne ci-dessus permet de déclarer l'encodage, l'UTF-8 est recommandé.

# Importation des modules nécessaires.
import globalPluginHandler
from conf import conf
import addonHandler
import keyLabels
from dialog import ModifyLockAnnouncementDialog
import gui
import wx
import os

# Pour les traductions.
addonHandler.initTranslation()
# Ces quelques lignes devraient nous permettre de récupérer le summary de notre addon.
_addonDir = os.path.join(os.path.dirname(__file__), "..", "..").decode("mbcs") # Déclaration d'une variable pour le stockage du chemin de notre addon.
_curAddon = addonHandler.Addon(_addonDir) # Déclaration d'un objet pour notre addon.
_addonSummary = _curAddon.manifest['summary'] # Déclaration d'une variable pour le stockage du summary.

# Déclaration d'une classe GlobalPlugin, dérivée de globalPluginHandler.GlobalPlugin.
class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	# On affecte la catégorie des scripts de notre addon à la variable _addonSummary déclarée plus haut.
	scriptCategory = _addonSummary

	def __init__(self, *args, **kwargs):
		# Constructeur de notre classe.
		# On appelle le constructeur de la classe mère.
		super(GlobalPlugin, self).__init__(*args, **kwargs)
		# On vérifie, au lancement de NVDA, les valeurs enregistrées pour l'activation ou non de l'annonce par défaut des touches numLock, capsLock et scrollLock.
		# La modification de la clé de dictionnaire keyLabels.localizedKeyLabel["nomDeLaClé"] permet de modicier l'annonce de la touche de verrouillage correspondante.
		# Pour numLock.
		keyLabels.localizedKeyLabels["numlock"] = _(conf["option"]["numLockLabel"])
		# Pour capsLock.
		keyLabels.localizedKeyLabels["capslock"] = _(conf["option"]["capsLockLabel"])
		# Pour scrollLock.
		keyLabels.localizedKeyLabels["scrolllock"] = _(conf["option"]["scrollLockLabel"])
		# On crée le menu.
		self.createSubMenu()

	def createSubMenu(self):
		# On crée un objet self.preferencesMenu qui pointera vers le menu Préférences de NVDA.
		self.preferencesMenu = gui.mainFrame.sysTrayIcon.preferencesMenu
		# On crée un sous-menu self.modifyLockAnnouncement pour notre boîte de configuration.
		self.modifyLockAnnouncement = self.preferencesMenu.Append(wx.ID_ANY, _(u"Modification of the announcement of num &lock, caps lock and scroll lock keys"), "")
		# On afecte l'action de notre sous-menu à la méthode self.onModifyLockAnnouncementDialog implémentée plus bas.
		gui.mainFrame.sysTrayIcon.Bind(wx.EVT_MENU, self.onModifyLockAnnouncementDialog, self.modifyLockAnnouncement)

	def terminate(self):
		# Cette méthode est indispensable lors de la création de nouveaux menu.
		# C'est une méthode destructeur, qui gère l'action de la suppression du menu en cas de besoin.
		try:
			self.preferencesMenu.RemoveItem(self.modifyLockAnnouncement)
		except wx.PyDeadObjectError:
			pass

	def onModifyLockAnnouncementDialog(self, evt):
		# Méthode permettant de gérer l'action du nouvel item ajouté dans le menu Préférences.
		# On ouvre notre boîte de dialogue implémentée dans le module dialog.py.
		# Pour que notre boîte de dialogue dérivée de gui.settingsDialogs.SettingsDialog s'affiche de façon cohérente avec les autres boîtes de configuration de NVDA, on doit l'appeler en paramètre de la méthode gui.mainFrame._popupSettingsDialog().
		gui.mainFrame._popupSettingsDialog(ModifyLockAnnouncementDialog)

	def script_activateModifyLockAnnouncementConfigurationDialog(self, gesture):
		# Ceci est notre script, qui n'est par défaut assigné à aucune touche de raccourci, on pourra le faire dans les gestes de commandes.
		wx.CallAfter(self.onModifyLockAnnouncementDialog, gui.mainFrame)
	# Documentation de notre script, qui sera consultable dans le mode aide-clavier.
	script_activateModifyLockAnnouncementConfigurationDialog.__doc__ = _(u"Allows you to display the configuration dialog box of the modification of the announcement of Num Lock, caps lock and scroll lock keys.")
