# -*- coding:utf-8 -*-
# La ligne ci-dessus permet de déclarer l'encodate, l'UTF-8 est recommandé.

# Importation des modules nécessaires.
import os
from cStringIO import StringIO
import logHandler
from validate import Validator
from configobj import ConfigObj

# Déclaration d'une variable pour le nom de notre fichier de config.
CONFIG_FILENAME = "configuration.ini"
# Déclaration d'une variable pour le chemin de notre fichier de config qui n'est autre que la racine de notre addon.
CONFIG_FILEPATH = os.path.join(os.path.dirname(__file__), "..", "..", CONFIG_FILENAME).decode("mbcs")

# Ci-dessous, on crée le modèle de configuration confspec, qui devrait comporter les valeurs par défaut des clés de configurations.
# La fonction boolean(default=False) permet de définir une valeur par défaut à chacune des clés à valeurs booléennes.
# La fonction string(default=...) permet de définir une valeur par défaut à chacune des clés à valeurs de type texte.
# On utilise l'objet StringIO qui va enregistrer ces valeurs comme si elles étaient dans un fichier de configuration.

confspec=ConfigObj(StringIO(
""" # modifyLockAnnouncement configuration file
[option]
defaultNumLock=boolean(default=True)
defaultCapsLock=boolean(default=True)
defaultScrollLock=boolean(default=True)
numLockLabel=string(default={nlLabel})
capsLockLabel=string(default={clLabel})
scrollLockLabel=string(default={slLabel})
""".format(nlLabel=_("num lock").encode("utf-8"), clLabel=_("caps lock").encode("utf-8"), slLabel=_("scroll lock").encode("utf-8"))
), list_values=False, encoding="UTF-8") # Le paramètre list_values doit être défini sur False et  le paramètre encoding doit être sur "UTF-8".
confspec.newLines = "\r\n" # On définit nos sauts de lignes de type "\r\n".

# L'instruction ci-dessous nous permet d'appliquer notre configuration.
# Le premier paramètre de la classe ConfigObj est notre fichier de configuration, le second notre configuration confspec par défaut implémentée plus haut et le troisième l'encoding, qui doit être "UTF-8".
conf=ConfigObj(CONFIG_FILEPATH, configspec = confspec, encoding = "UTF-8")

# L'instruction plus bas permet de valider notre configuration de telle manière que la configuration par défaut soit celle du confspec implémentée plus haut dans l'absence d'un fichier de configuration, sinon, ce sera le fichier de configuration qui primera si ces clés comportent des valeurs différentes que les valeurs par défaut.
val = Validator()

# Si la variable plus bas retourne True c'est que tout est bon, il faut d'abord tester son retour pour être certain que notre configuration fonctionnera.
# Par exemple, essayer de tracer dans le journal avec un logHandler.log.info(str(result)).
result = conf.validate(val)

# On trace, à toutes fins utiles, si tout va bien, on devrait avoir un True dans le journal.
logHandler.log.info(str(result))