# -*- coding: utf-8 -*-
# La ligne ci-dessus permet de déclarer l'encodage, l'UTF-8 est recommandé.

# Importation des modules nécessaires.
import addonHandler
import keyLabels
from conf import conf, CONFIG_FILEPATH
from gui.settingsDialogs import SettingsDialog # Pour la création de la boîte de dialogue de configuration.
import gui
import wx
import os

# Pour les traductions.
addonHandler.initTranslation()

# On crée ci-dessous, une classe ModifyLocAnnouncementDialog, dérivé de la classe gui.settingsDialogs.SettingsDialog.
class ModifyLockAnnouncementDialog(SettingsDialog):
	# Dans cette classe dérivée de la classe SettingsDialog, on a juste à définir un attribut title et certaines méthodes qui seront décrites plus bas.
	title = _(u"Modification of the announcements of num lock, caps lock and scroll lock keys")

	def __init__(self, *args, **kwargs):
		# Ceci est notre fonction constructeur.
		# On appelle le constructeur de la classe parente.
		super(ModifyLockAnnouncementDialog, self).__init__(*args, **kwargs)
		# On définit les annonces par défaut de nos touches de verrouillage, à partir du fichier de config.
		self.numLockLabel = conf["option"]["numLockLabel"]
		self.capsLockLabel = conf["option"]["capsLockLabel"]
		self.scrollLockLabel = conf["option"]["scrollLockLabel"]

	def makeSettings(self, settingsSizer):
		# Cette méthode makeSettings, est redéfinie de la classe mère, elle doit comporter les différents widgets.
		# Son paramètre settingsSizer est le fameux sizer qui devrait permettre un affichage cohérent avec les autres boîtes de dialogues de configuration utilisées par NVDA.
		# Celà facilite grandement le travail du scripteur.
		# Ci-dessous, on crée un Sizer dialogSizer, à orientation verticale qui comportera les cases à cocher pour l'activation ou non des annonces par défaut, il sera ensuite inclu dans le settingsSizer principal.
		dialogSizer=wx.BoxSizer(wx.VERTICAL)
		# Création d'une checkBox pour l'activation de l'annonce par défaut de la touche verrouillage numérique.
		# Tout d'abord, on lui définit un ID.
		defaultNumLockID = wx.NewId()
		self.defaultNumLock=wx.CheckBox(parent = self, id=defaultNumLockID, label=_(u"Enable the default announcement of num lock key"))
		# Son état coché ou décoché est extrait de la clé defaultNumLock définie dans le fichier de configuration.
		self.defaultNumLock.SetValue(conf["option"]["defaultNumLock"])
		# On ajoute notre checkbox dans notre Sizer dialogSizer.
		dialogSizer.Add(item=self.defaultNumLock)
		# Création d'une checkBox pour l'activation de l'annonce par défaut de la touche verrouillage majuscule.
		# Tout d'abord, on lui définit un ID.
		defaultCapsLockID = wx.NewId()
		self.defaultCapsLock=wx.CheckBox(parent = self, id = defaultCapsLockID, label=_(u"Enable the default announcement of caps lock key"))
		# Son état coché ou décoché est extrait de la clé defaultCapsLock définie dans le fichier de configuration.
		self.defaultCapsLock.SetValue(conf["option"]["defaultCapsLock"])
		# On ajoute notre checkbox dans notre Sizer dialogSizer.
		dialogSizer.Add(item=self.defaultCapsLock)
		# Création d'une checkBox pour l'activation de l'annonce par défaut de la touche arrêt défilement.
		# Tout d'abord, on lui définit un ID.
		defaultScrollLockID = wx.NewId()
		self.defaultScrollLock=wx.CheckBox(parent = self, id = defaultScrollLockID, label=_(u"Enable the default announcement of scroll lock key"))
		# Son état coché ou décoché est extrait de la clé defaultScrollLock définie dans le fichier de configuration.
		self.defaultScrollLock.SetValue(conf["option"]["defaultScrollLock"])
		# On ajoute notre checkbox dans notre Sizer dialogSizer.
		dialogSizer.Add(item=self.defaultScrollLock)
		# On ajoute notre Sizer dialogSizer dans le Sizer principal settingsSizer.
		settingsSizer.Add(dialogSizer, border=10, flag=wx.BOTTOM)
		# Création d'un sizer entryButtonsSizer à orientation horizontal pour l'ajout des boutons de modification des annonces des touches de verrouillage.
		entryButtonsSizer=wx.BoxSizer(wx.HORIZONTAL)
		# On crée un bouton pour la modification de l'annonce de la touche num lock.
		# Tout d'abord, on lui définit un ID.
		modifyNumLockButtonID=wx.NewId()
		self.modifyNumLockButton=wx.Button(self, modifyNumLockButtonID, _("Modify &num lock announce"),)
		# On ajoute notre bouton dans le sizer entryButtonsSizer.
		entryButtonsSizer.Add(self.modifyNumLockButton)
		if self.defaultNumLock.IsChecked():
			# On affiche ce bouton de manière conditionnelle à l'état de la case à cocher pour l'annonce par défaut de la touche num lock.
			# Si elle est cochée, ce bouton ne sera pas affiché.
			self.modifyNumLockButton.Disable()
		# On crée un bouton pour la modification de l'annonce de la touche caps lock.
		# Tout d'abord, on lui définit un ID.
		modifyCapsLockButtonID=wx.NewId()
		self.modifyCapsLockButton=wx.Button(self, modifyCapsLockButtonID, _("Modify &caps lock announce"))
		# On ajoute notre bouton dans le sizer entryButtonsSizer.
		entryButtonsSizer.Add(self.modifyCapsLockButton)
		if self.defaultCapsLock.IsChecked():
			# On affiche ce bouton de manière conditionnelle à l'état de la case à cocher pour l'annonce par défaut de la touche caps lock.
			# Si elle est cochée, ce bouton ne sera pas affiché.
			self.modifyCapsLockButton.Disable()
		# On crée un bouton pour la modification de l'annonce de la touche scroll lock.
		# Tout d'abord, on lui définit un ID.
		modifyScrollLockButtonID=wx.NewId()
		self.modifyScrollLockButton=wx.Button(self, modifyScrollLockButtonID, _("Modify &scroll lock announce"))
		# On ajoute notre bouton dans le sizer entryButtonsSizer.
		entryButtonsSizer.Add(self.modifyScrollLockButton)
		if self.defaultScrollLock.IsChecked():
			# On affiche ce bouton de manière conditionnelle à l'état de la case à cocher pour l'annonce par défaut de la touche scroll lock.
			# Si elle est cochée, ce bouton ne sera pas affiché.
			self.modifyScrollLockButton.Disable()
		# Définition d'un événement pour le cochage ou non de la case de l'annonce par défaut de la touche num lock.
		wx.EVT_CHECKBOX(self, defaultNumLockID, self.OnCheckNumLock)
		# Définition d'un événement pour le cochage ou non de la case de l'annonce par défaut de la touche caps lock.
		wx.EVT_CHECKBOX(self, defaultCapsLockID, self.OnCheckCapsLock)
		# Définition d'un événement pour le cochage ou non de la case de l'annonce par défaut de la touche scroll lock.
		wx.EVT_CHECKBOX(self, defaultScrollLockID, self.OnCheckScrollLock)
		# Événements des boutons de modification des annonces.
		self.Bind(wx.EVT_BUTTON, self.OnModifyNumLockLabel, id=modifyNumLockButtonID)
		self.Bind(wx.EVT_BUTTON, self.OnModifyCapsLockLabel, id=modifyCapsLockButtonID)
		self.Bind(wx.EVT_BUTTON, self.OnModifyScrollLockLabel, id=modifyScrollLockButtonID)
		# On ajoute le sizer entryButtonsSizer dans notre settingsSizer principal.
		settingsSizer.Add(entryButtonsSizer)

	def postInit(self):
		# Cette méthode permet tout simplement de spécifier quel widget prendra le focus, on choisira le widget self.defaultNumLock.
		self.defaultNumLock.SetFocus()

	def OnCheckNumLock(self, evt):
		if self.defaultNumLock.IsChecked():
			# Cette fonction est associée à l'événement de la coche ou non de la touche numLock.
			# Si la case de lannonce par défaut de la touche num lock est cochée, le bouton de modification de l'annonce de cette touche ne sera pas affiché.
			self.modifyNumLockButton.Disable()
		else:
			# La case est décochée, on peut donc afficher ce bouton de modification de l'annonce de la touche num lock.
			self.modifyNumLockButton.Enable()

	def OnCheckCapsLock(self, evt):
		# Cette fonction est associée à l'événement de la coche ou non de la touche capsLock.
		if self.defaultCapsLock.IsChecked():
			# Si la case de lannonce par défaut de la touche caps lock est cochée, le bouton de modification de l'annonce de cette touche ne sera pas affiché.
			self.modifyCapsLockButton.Disable()
		else:
			# La case est décochée, on peut donc afficher ce bouton de modification de l'annonce de la touche caps lock.
			self.modifyCapsLockButton.Enable()

	def OnCheckScrollLock(self, evt):
		# Cette fonction est associée à l'événement de la coche ou non de la touche scrollLock.
		if self.defaultScrollLock.IsChecked():
			# Si la case de lannonce par défaut de la touche scroll lock est cochée, le bouton de modification de l'annonce de cette touche ne sera pas affiché.
			self.modifyScrollLockButton.Disable()
		else:
			# La case est décochée, on peut donc afficher ce bouton de modification de l'annonce de la touche scroll lock.
			self.modifyScrollLockButton.Enable()

	def OnModifyNumLockLabel(self, evt):
		# Fonction permettant de gérer la modification de l'annonce de la touche num lock.
		with wx.TextEntryDialog(self, _("New announce:"), _("redefine num lock announce"), defaultValue=keyLabels.localizedKeyLabels["numlock"]) as d:
			while True:
				if d.ShowModal() == wx.ID_OK:
					# On a validé sur OK.
					if d.Value == "":
						# On a rien écrit, on affiche une boîte messageBox invitant l'utilisateur à refaire une tentative.
						gui.messageBox(_(u"You have not written anything !"), _("No entry"), wx.OK|wx.ICON_WARNING, self)
					else:
						# On a bien écrit quelque chose, on l'affecte à la variable d'instance self.numLockLabel.
						self.numLockLabel = d.Value
						# On remet le focus sur notre bouton de modification de l'annonce de la touche num lock.
						self.modifyNumLockButton.SetFocus()
						# On quitte la fonction.
						return
				else:
					# On a validé sur le bouton annuler, ou pressé la touche échappe.
					# On stoppe l'itération.
					break
					# On remet le focus sur notre bouton de modification de l'annonce de la touche num lock.
					self.modifyNumLockButton.SetFocus()

	def OnModifyCapsLockLabel(self, evt):
		# Fonction permettant de gérer la modification de l'annonce de la touche caps lock.
		with wx.TextEntryDialog(self, _("New announce:"), _("redefine caps lock label"), defaultValue=keyLabels.localizedKeyLabels["capslock"]) as d:
			while True:
				if d.ShowModal() == wx.ID_OK:
					# On a validé sur OK.
					if d.Value == "":
						# On a rien écrit, on affiche une boîte messageBox invitant l'utilisateur à refaire une tentative.
						gui.messageBox(_(u"You have not written anything !"), _("No entry"), wx.OK|wx.ICON_WARNING, self)
					else:
						# On a bien écrit quelque chose, on l'affecte à la variable d'instance self.capsLockLabel.
						self.capsLockLabel = d.Value
						# On remet le focus sur notre bouton de modification de l'annonce de la touche caps lock.
						self.modifyCapsLockButton.SetFocus()
						# On quitte la fonction.
						return
				else:
					# On a validé sur le bouton annuler, ou pressé la touche échappe.
					# On stoppe l'itération.
					break
					# On remet le focus sur notre bouton de modification de l'annonce de la touche caps lock.
					self.modifyCapsLockButton.SetFocus()

	def OnModifyScrollLockLabel(self, evt):
		# Fonction permettant de gérer la modification de l'annonce de la touche scroll lock.
		with wx.TextEntryDialog(self, _("New announce:"), _("redefine scroll lock label"), defaultValue=keyLabels.localizedKeyLabels["scrolllock"]) as d:
			while True:
				if d.ShowModal() == wx.ID_OK:
					# On a validé sur OK.
					if d.Value == "":
						# On a rien écrit, on affiche une boîte messageBox invitant l'utilisateur à refaire une tentative.
						gui.messageBox(_(u"You have not written anything !"), _("No entry"), wx.OK|wx.ICON_WARNING, self)
					else:
						# On a bien écrit quelque chose, on l'affecte à la variable d'instance self.scrollLockLabel.
						self.scrollLockLabel = d.Value
						# On remet le focus sur notre bouton de modification de l'annonce de la touche scroll lock.
						self.modifyScrollLockButton.SetFocus()
						# On quitte la fonction.
						return
				else:
					# On a validé sur le bouton annuler, ou pressé la touche échappe.
					# On stoppe l'itération.
					break
					# On remet le focus sur notre bouton de modification de l'annonce de la touche scroll lock.
					self.modifyScrollLockButton.SetFocus()

	def onOk(self, evt):
		# Cette méthode onOk doit aussi être redéfinie de la classe mère, pour gérer l'événement du click sur le bouton OK.
		# On affecte l'état coché ou pas de l'activation de l'annonce par défaut de la touche numLock à la clé correspondante dans le fichier de config.
		conf["option"]["defaultNumLock"] = self.defaultNumLock.GetValue()
		# On affecte l'état coché ou pas de l'annonce par défaut de l'abréviation de la touche capsLock à la clé correspondante dans le fichier de config.
		conf["option"]["defaultCapsLock"] = self.defaultCapsLock.GetValue()
		# On affecte l'état coché ou pas de l'activation de l'annonce par défaut de la touche scrollLock à la clé correspondante dans le fichier de config.
		conf["option"]["defaultScrollLock"] = self.defaultScrollLock.GetValue()
		if self.defaultNumLock.GetValue():
			# L'utilisateur a coché la case pour l'annonce par défaut du numLock.
			# On garde la valeur par défaut de cette clé, il n'y aura pas de changements.
			conf["option"].restore_default("numLockLabel")
			conf.write()
			keyLabels.localizedKeyLabels["numlock"] = conf["option"]["numLockLabel"]
		else:
			# L'utilisateur a personnalisé l'annonce du numLock.
			#On prends en compte ses modifications dans le fichier de configuration.
			conf["option"]["numLockLabel"] = self.numLockLabel
			conf.write()
			keyLabels.localizedKeyLabels["numlock"] = self.numLockLabel
		if self.defaultCapsLock.GetValue():
			# L'utilisateur a coché la case pour l'annonce par défaut du capsLock.
			# On garde la valeur par défaut de cette clé, il n'y aura pas de changements.
			conf["option"].restore_default("capsLockLabel")
			conf.write()
			keyLabels.localizedKeyLabels["capslock"] = conf["option"]["capsLockLabel"]
		else:
			# L'utilisateur a personnalisé l'annonce du capsLock.
			#On prends en compte ses modifications dans le fichier de configuration.
			conf["option"]["capsLockLabel"] = self.capsLockLabel
			conf.write()
			keyLabels.localizedKeyLabels["capslock"] = self.capsLockLabel
		if self.defaultScrollLock.GetValue():
			# L'utilisateur a coché la case pour l'annonce par défaut du scrollLock.
			# On garde la valeur par défaut de cette clé, il n'y aura pas de changements.
			conf["option"].restore_default("scrollLockLabel")
			conf.write()
			keyLabels.localizedKeyLabels["scrolllock"] = conf["option"]["scrollLockLabel"]
		else:
			# L'utilisateur a personnalisé l'annonce du scrollLock.
			#On prends en compte ses modifications dans le fichier de configuration.
			conf["option"]["scrollLockLabel"] = self.scrollLockLabel
			conf.write()
			keyLabels.localizedKeyLabels["scrolllock"] = self.scrollLockLabel
		if conf["option"]["defaultNumLock"] and conf["option"]["defaultCapsLock"] and conf["option"]["defaultScrollLock"]:
			# Toutes les cases sont cochées, le fichier de configuration est inutile, on le supprime.
			os.remove(CONFIG_FILEPATH)
		# Là il est conseillé d'appeler la méthode onOk parente pour la fermeture correcte de la boîte de dialogue.
		super(ModifyLockAnnouncementDialog, self).onOk(evt)

# Inutile de redéfinir la méthode onCancel, car on a rien à y ajouter.
